==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebColumnComponentEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnDescriptionMetadata } from "./WebColumnDescriptionMetadata";
import { WebColumnComponentEventArgsDescription } from "./WebColumnComponentEventArgsDescription";
/**
 * @hidden
 */
export let WebColumnComponentEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebColumnComponentEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebColumnComponentEventArgsDescriptionMetadata.a == null) {
                WebColumnComponentEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebColumnComponentEventArgsDescriptionMetadata.c(WebColumnComponentEventArgsDescriptionMetadata.a);
            }
            if (a.j(WebColumnComponentEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(WebColumnComponentEventArgsDescriptionMetadata.a);
            WebColumnDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ColumnComponentEventArgs");
            a.item("Detail", "ExportedType:WebColumn");
        }
        static d(a) {
            WebColumnComponentEventArgsDescriptionMetadata.b(a);
            a.aa("WebColumnComponentEventArgs", () => new WebColumnComponentEventArgsDescription());
            a.z("WebColumnComponentEventArgs", WebColumnComponentEventArgsDescriptionMetadata.a);
        }
    }
    WebColumnComponentEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebColumnComponentEventArgsDescriptionMetadata, 'WebColumnComponentEventArgsDescriptionMetadata');
    WebColumnComponentEventArgsDescriptionMetadata.a = null;
    return WebColumnComponentEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebColumnComponentEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnDescriptionMetadata } from "./WebColumnDescriptionMetadata";
import { WebColumnComponentEventArgsDescription } from "./WebColumnComponentEventArgsDescription";
/**
 * @hidden
 */
export let WebColumnComponentEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebColumnComponentEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebColumnComponentEventArgsDescriptionMetadata.a == null) {
                WebColumnComponentEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebColumnComponentEventArgsDescriptionMetadata.c(WebColumnComponentEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebColumnComponentEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebColumnComponentEventArgsDescriptionMetadata.a);
            WebColumnDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ColumnComponentEventArgs");
            a.item("Detail", "ExportedType:WebColumn");
        }
        static d(a) {
            WebColumnComponentEventArgsDescriptionMetadata.b(a);
            a.ac("WebColumnComponentEventArgs", () => new WebColumnComponentEventArgsDescription());
            a.ab("WebColumnComponentEventArgs", WebColumnComponentEventArgsDescriptionMetadata.a);
        }
    }
    WebColumnComponentEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebColumnComponentEventArgsDescriptionMetadata, 'WebColumnComponentEventArgsDescriptionMetadata');
    WebColumnComponentEventArgsDescriptionMetadata.a = null;
    return WebColumnComponentEventArgsDescriptionMetadata;
})();
